## run CTE

source('CTE.R')

diseaseNames <- c("T2D","AMD","T1D","MI")

## set initial parameters
num.geno.samples <- 1e5
#num.beta.samples <- 100
num.beta.samples <- 10
num.hist.breaks <- 25
num.frac.targeted <- 1000

#AUCs <- c(0.55,0.6,0.65,0.7,0.75,0.8,0.85,0.9,0.95)
#AUCs <- c(0.79, 0.81, 0.93, 0.84)

i <- 0
for(d in diseaseNames) {
  i <- i+1
  prefix = paste("results/CTE.a",d,sep=".",collapse="")
  print(d);
  params <- InitParams(d)

  ## Histogram, ROC
  print ( system.time ( SampleAndWriteHistogramAndROC(params, prefix, num.geno.samples, num.beta.samples, num.hist.breaks) ) );
  #print ( system.time ( SampleAndWriteHistogram(params, prefix, num.geno.samples, num.beta.samples, num.hist.breaks) ) );

  ## compute heritability from AUC
  AUC.GWAS.pop <- as.double(read.table(paste(c(prefix,"auc"),collapse="."))[1,2])
  
  ## hsq is assumed to be independent of prevalence  
  hsq.GWAS <- Wray.AUC(params$preval,AUC.GWAS.pop)$hsq

  params$pi.c <- params$preval
  params$pi.t <- params$preval/2
  ## Enrichment Trial based on GWAS
  print ( system.time ( SampleAndWriteForEnrichmentTrial(params, prefix, num.geno.samples, num.beta.samples, num.frac.targeted) ) );
  
  ## 50% heritability
  hsq.max <- Wray.sibrisk(params$preval,params$sibrisk)$hsq
  hsq.half <- hsq.max/2
  hsq.quarter <- hsq.max/4
  AUC.half <- Wray.hsq(params$preval,hsq.half)$AUC
  AUC.quarter <- Wray.hsq(params$preval,hsq.quarter)$AUC

  print(paste("AUC.half",AUC.half,collapse="="))
  print(paste("AUC.quarter",AUC.quarter,collapse="="))
  
  print( system.time (GeneralRiskEnrichmentTrial(params, AUC.half, paste(c(prefix,"half"),collapse=".") ,num.geno.samples,num.frac.targeted) ) )
  print( system.time (GeneralRiskEnrichmentTrial(params, AUC.quarter, paste(c(prefix,"quarter"),collapse=".") ,num.geno.samples,num.frac.targeted) ) )  
}
